@@ -3,6 +3,7 @@ import os
 from nopecha.nopecha import (
     Recognition,
     Token,
+    Balance,
 )
 from nopecha.error import NopeCHAError, InvalidRequestError, IncompleteJobError, RateLimitError, AuthenticationError, InsufficientCreditError, UnknownError, Timeout, APIError, ServiceUnavailableError
 
@@ -13,6 +14,7 @@ proxy = None
 __all__ = [
     "Recognition",
     "Token",
+    "Balance",
 
     "NopeCHAError",
     "InvalidRequestError",
